@@ -1,44 +1,29 @@
 /*
-    Copyright 2009 Harald Fernengel <harry@kdevelop.org>
-    Copyright 2017 René J.V. Bertin <rjvbertin@gmail.com>
+    SPDX-FileCopyrightText: 2009 Harald Fernengel <harry@kdevelop.org>
+    SPDX-FileCopyrightText: 2017 René J.V. Bertin <rjvbertin@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library. If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "iokitdevice.h"
-#include "iokitgenericinterface.h"
-#include "iokitprocessor.h"
 #include "iokitbattery.h"
+#include "iokitgenericinterface.h"
+#include "iokitopticaldisc.h"
+#include "iokitopticaldrive.h"
+#include "iokitprocessor.h"
 #include "iokitstorage.h"
 #include "iokitstorageaccess.h"
 #include "iokitvolume.h"
-#include "iokitopticaldrive.h"
-#include "iokitopticaldisc.h"
 
 #include <QDebug>
 #include <QSet>
 #include <QUrl>
 
-#include <sys/types.h>
 #include <sys/sysctl.h>
+#include <sys/types.h>
 
-#include <IOKit/IOKitLib.h>
-#include <IOKit/usb/IOUSBLib.h>
 #include <IOKit/network/IOEthernetInterface.h>
+#include <IOKit/usb/IOUSBLib.h>
 
 #include <CoreFoundation/CoreFoundation.h>
 
@@ -54,11 +39,8 @@ namespace Backends
 {
 namespace IOKit
 {
-
 // returns a solid type from an entry and its properties
-static DeviceInterfaceTypes typesFromEntry(const io_registry_entry_t &entry,
-        const QMap<QString, QVariant> &properties,
-        Solid::DeviceInterface::Type &mainType)
+static DeviceInterfaceTypes typesFromEntry(const io_registry_entry_t &entry, const QMap<QString, QVariant> &properties, Solid::DeviceInterface::Type &mainType)
 {
     DeviceInterfaceTypes types;
     mainType = Solid::DeviceInterface::Unknown;
@@ -70,17 +52,16 @@ static DeviceInterfaceTypes typesFromEntry(const io_registry_entry_t &entry,
         mainType = Solid::DeviceInterface::Battery;
         types << mainType;
     }
-    const QString bsdName = QStringLiteral("BSD Name"),
-        leaf = QStringLiteral("Leaf");
-    if (IOObjectConformsTo(entry, "IOCDMedia")
-        || IOObjectConformsTo(entry, "IODVDMedia")
+    const QString bsdName = QStringLiteral("BSD Name");
+    const QString leaf = QStringLiteral("Leaf");
+    if (IOObjectConformsTo(entry, "IOCDMedia") //
+        || IOObjectConformsTo(entry, "IODVDMedia") //
         || IOObjectConformsTo(entry, "IOBDMedia")) {
         mainType = Solid::DeviceInterface::OpticalDrive;
-        types << mainType
-            << Solid::DeviceInterface::OpticalDisc;
+        types << mainType << Solid::DeviceInterface::OpticalDisc;
     }
     if (properties.contains(bsdName) && properties.value(bsdName).toString().startsWith(QStringLiteral("disk"))) {
-        if ((properties.contains(leaf) && properties.value(leaf).toBool() == false)
+        if ((properties.contains(leaf) && properties.value(leaf).toBool() == false) //
             || mainType == Solid::DeviceInterface::OpticalDrive) {
             if (mainType == Solid::DeviceInterface::Unknown) {
                 mainType = Solid::DeviceInterface::StorageDrive;
@@ -94,7 +75,7 @@ static DeviceInterfaceTypes typesFromEntry(const io_registry_entry_t &entry,
 
     if (types.isEmpty()) {
         types << mainType;
-//         qWarning() << "unsupported entry" << entry << "with properties" << properties;
+        //         qWarning() << "unsupported entry" << entry << "with properties" << properties;
     }
 
     return types;
@@ -167,7 +148,7 @@ public:
     }
 
     void init(const QString &udiString, const io_registry_entry_t &entry);
-    IOKitDevice* getParentDevice();
+    IOKitDevice *getParentDevice();
 
     QString udi;
     QString parentUdi;
@@ -188,16 +169,14 @@ void IOKitDevicePrivate::init(const QString &udiString, const io_registry_entry_
     parentUdi = getParentDeviceUdi(entry);
     type = typesFromEntry(entry, properties, mainType);
     if (udi.contains(QStringLiteral("IOBD")) || udi.contains(QStringLiteral("BD PX"))) {
-        qWarning() << "Solid: BlueRay entry" << entry << "mainType=" << mainType << "typeList:" << type
-            << "with properties" << properties;
-    }
-    if (mainType != Solid::DeviceInterface::Unknown) {
+        qWarning() << "Solid: BlueRay entry" << entry << "mainType=" << mainType << "typeList:" << type << "with properties" << properties;
     }
+    if (mainType != Solid::DeviceInterface::Unknown) { }
 
     IOObjectRelease(entry);
 }
 
-IOKitDevice* IOKitDevicePrivate::getParentDevice()
+IOKitDevice *IOKitDevicePrivate::getParentDevice()
 {
     if (!parentDevice) {
         parentDevice = new IOKitDevice(parentUdi);
@@ -219,9 +198,7 @@ IOKitDevice::IOKitDevice(const QString &udi)
         return;
     }
 
-    io_registry_entry_t entry = IORegistryEntryFromPath(
-                                    kIOMasterPortDefault,
-                                    udi.toLocal8Bit().constData());
+    io_registry_entry_t entry = IORegistryEntryFromPath(kIOMasterPortDefault, udi.toLocal8Bit().constData());
 
     if (entry == MACH_PORT_NULL) {
         qWarning() << Q_FUNC_INFO << "Tried to create Device from invalid UDI" << udi;
@@ -239,9 +216,7 @@ IOKitDevice::IOKitDevice(const IOKitDevice &device)
         return;
     }
 
-    io_registry_entry_t entry = IORegistryEntryFromPath(
-                                    kIOMasterPortDefault,
-                                    device.udi().toLocal8Bit().constData());
+    io_registry_entry_t entry = IORegistryEntryFromPath(kIOMasterPortDefault, device.udi().toLocal8Bit().constData());
 
     if (entry == MACH_PORT_NULL) {
         qWarning() << Q_FUNC_INFO << "Tried to create Device from invalid UDI" << device.udi();
@@ -260,9 +235,7 @@ bool IOKitDevice::conformsToIOKitClass(const QString &className) const
 {
     bool conforms = false;
     if (!className.isEmpty()) {
-        io_registry_entry_t entry = IORegistryEntryFromPath(
-                                    kIOMasterPortDefault,
-                                    udi().toLocal8Bit().constData());
+        io_registry_entry_t entry = IORegistryEntryFromPath(kIOMasterPortDefault, udi().toLocal8Bit().constData());
         if (entry != MACH_PORT_NULL) {
             conforms = IOObjectConformsTo(entry, className.toLocal8Bit().constData());
             IOObjectRelease(entry);
@@ -384,9 +357,10 @@ QString IOKitDevice::icon() const
             break;
         case Solid::StorageDrive::CdromDrive: {
             const IOKitOpticalDisc disc(this);
-            if (disc.availableContent() == Solid::OpticalDisc::Audio ) {
+            if (disc.availableContent() == Solid::OpticalDisc::Audio) {
                 return QStringLiteral("media-optical-audio");
-            } else switch (disc.discType()) {
+            } else
+                switch (disc.discType()) {
                 case Solid::OpticalDisc::CdRom:
                     return QStringLiteral("media-optical-data");
                     break;
@@ -399,7 +373,7 @@ QString IOKitDevice::icon() const
                 case Solid::OpticalDisc::BluRayRewritable:
                     return QStringLiteral("media-optical-blu-ray");
                     break;
-            }
+                }
             break;
         }
         case Solid::StorageDrive::SdMmc:
@@ -464,7 +438,7 @@ bool IOKitDevice::queryDeviceInterface(const Solid::DeviceInterface::Type &type)
         return true;
         break;
     case Solid::DeviceInterface::StorageAccess:
-        if (d->type.contains(Solid::DeviceInterface::StorageDrive)
+        if (d->type.contains(Solid::DeviceInterface::StorageDrive) //
             || d->type.contains(Solid::DeviceInterface::StorageVolume)) {
             return true;
         }
@@ -526,7 +500,7 @@ QObject *IOKitDevice::createDeviceInterface(const Solid::DeviceInterface::Type &
         }
         break;
     case Solid::DeviceInterface::StorageAccess:
-        if (d->type.contains(Solid::DeviceInterface::StorageDrive)
+        if (d->type.contains(Solid::DeviceInterface::StorageDrive) //
             || d->type.contains(Solid::DeviceInterface::StorageVolume)) {
             iface = new IOKitStorageAccess(this);
         }
@@ -540,4 +514,3 @@ QObject *IOKitDevice::createDeviceInterface(const Solid::DeviceInterface::Type &
 }
 }
 } // namespaces
-
